@@ -23,7 +23,7 @@ sub render_subfield {
 
     my $output = $subfield->render($subresult);
     if ( $self->wrap_repeatable_element_method ) {
-        $output = $self->wrap_repeatable_element($output);
+        $output = $self->wrap_repeatable_element($output, $subfield->name);
     }
     return $output;
 }
@@ -43,7 +43,7 @@ HTML::FormHandler::Widget::Field::Repeatable - repeatable field widget
 
 =head1 VERSION
 
-version 0.40058
+version 0.40059
 
 =head1 SYNOPSIS
 
